/// <reference types="hapi__joi" />
import type { IDynamoQueryParamOptions, ISecondaryIndexDef, IFieldCondition, IDynamoQuerySecondayIndexOptions } from "../types";
import type { DynamoDB } from "aws-sdk";
import type { DocumentClient } from "aws-sdk/clients/dynamodb";
import Joi from "@hapi/joi";
import BaseMixins from "../core/base-mixins";
interface IDynamoOptions<T> {
    dynamoDb: () => DynamoDB;
    schemaDef: Joi.SchemaMap;
    dynamoDbClient: () => DocumentClient;
    dataKeyGenerator: () => string;
    featureIdentityValue: string;
    secondaryIndexOptions: ISecondaryIndexDef<T>[];
    baseTableName: string;
    strictRequiredFields: (keyof T)[] | string[];
}
export declare abstract class DynamoDataOperation<T> extends BaseMixins {
    private readonly here_partitionKeyFieldName;
    private readonly here_sortKeyFieldName;
    private readonly here_dynamoDbClient;
    private readonly here_dynamoDb;
    private readonly here_dataKeyGenerator;
    private readonly here_schema;
    private readonly here_marshaller;
    private readonly here_tableFullName;
    private readonly here_strictRequiredFields;
    private readonly here_featureIdentityValue;
    private readonly here_secondaryIndexOptions;
    constructor({ dynamoDb, schemaDef, dynamoDbClient, secondaryIndexOptions, featureIdentityValue, baseTableName, strictRequiredFields, dataKeyGenerator, }: IDynamoOptions<T>);
    private _dynamoDbClient;
    private _dynamoDb;
    private generateDynamoTableKey;
    private _getLocalVariables;
    private _getBaseObject;
    private _checkValidateMustBeAnObjectDataType;
    private _checkValidateStrictRequiredFields;
    protected allCreateOneBase({ data }: {
        data: T;
    }): Promise<T>;
    private withConditionPassed;
    protected allGetOneByIdBase({ dataId, withCondition, }: {
        dataId: string;
        withCondition?: IFieldCondition<T>;
    }): Promise<T | null>;
    protected allGetOneByIdProjectBase<TExpectedVals = T>({ dataId, projectionAttributes, withCondition, }: {
        dataId: string;
        projectionAttributes: (keyof TExpectedVals)[];
        withCondition?: IFieldCondition<T>;
    }): Promise<any>;
    protected allUpdateOneDirectBase({ data }: {
        data: T;
    }): Promise<T>;
    protected allUpdateOneByIdBase({ dataId, data, withCondition, }: {
        dataId: string;
        data: T;
        withCondition?: IFieldCondition<T>;
    }): Promise<T>;
    private _allHelpValidateMarshallAndGetValue;
    protected allExistsByIdBase(dataId: string): Promise<boolean>;
    protected allQueryGetManyByConditionBase({ paramOptions, }: {
        paramOptions: IDynamoQueryParamOptions<T>;
    }): Promise<T[]>;
    protected allQueryGetManyByConditionPaginateBase({ paramOptions, }: {
        paramOptions: IDynamoQueryParamOptions<T>;
    }): Promise<import("../types").IDynamoPagingResult<T[]>>;
    protected allBatchGetManyByHashAndSortKey({ dataIds, fields, }: {
        dataIds: string[];
        fields?: (keyof T)[];
    }): Promise<T[]>;
    protected allQuerySecondaryIndexBase<T>(paramOption: IDynamoQuerySecondayIndexOptions<T>): Promise<T[]>;
    protected allQuerySecondaryIndexPaginateBase<T>(paramOption: IDynamoQuerySecondayIndexOptions<T>): Promise<import("../types").IDynamoPagingResult<T[]>>;
    protected allDeleteByIdBase({ dataId, }: {
        dataId: string;
    }): Promise<T>;
    protected allDeleteManyDangerouselyByIds({ dataIds, }: {
        dataIds: string[];
    }): Promise<boolean>;
}
export {};
